from setuptools import setup

setup(
    name='sbsha69',
    version='9.0.0',
    py_modules=['sbsha69'],
    author='PythonScratcher',
    author_email='me@psr.tf',
    description='Basic encryption algorithm',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/yourusername/sbsha69',
    license='MIT',
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ],
)
